searchData={"items":[{"type":"module","title":"Decimal","doc":"Decimal arithmetic on arbitrary precision floating-point numbers.\n\nA number is represented by a signed coefficient and exponent such that: `sign\n* coefficient * 10 ^ exponent`. All numbers are represented and calculated\nexactly, but the result of an operation may be rounded depending on the\ncontext the operation is performed with, see: `Decimal.Context`. Trailing\nzeros in the coefficient are never truncated to preserve the number of\nsignificant digits unless explicitly done so.\n\nThere are also special values such as NaN (not a number) and ±Infinity.\n-0 and +0 are two distinct values.\nSome operation results are not defined and will return NaN.\nThis kind of NaN is quiet, any operation returning a number will return\nNaN when given a quiet NaN (the NaN value will flow through all operations).\n\nExceptional conditions are grouped into signals, each signal has a flag and a\ntrap enabler in the context. Whenever a signal is triggered it's flag is set\nin the context and will be set until explicitly cleared. If the signal is trap\nenabled `Decimal.Error` will be raised.","ref":"Decimal.html"},{"type":"module","title":"Specifications - Decimal","doc":"* [IBM's General Decimal Arithmetic Specification](http://speleotrove.com/decimal/decarith.html)\n  * [IEEE standard 854-1987](http://web.archive.org/web/20150908012941/http://754r.ucbtest.org/standards/854.pdf)\n\nThis library follows the above specifications for reference of arithmetic\noperation implementations, but the public APIs may differ to provide a\nmore idiomatic Elixir interface.\n\nThe specification models the sign of the number as 1, for a negative number,\nand 0 for a positive number. Internally this implementation models the sign as\n1 or -1 such that the complete number will be `sign * coefficient *\n10 ^ exponent` and will refer to the sign in documentation as either *positive*\nor *negative*.\n\nThere is currently no maximum or minimum values for the exponent. Because of\nthat all numbers are \"normal\". This means that when an operation should,\naccording to the specification, return a number that \"underflows\" 0 is returned\ninstead of Etiny. This may happen when dividing a number with infinity.\nAdditionally, overflow, underflow and clamped may never be signalled.","ref":"Decimal.html#module-specifications"},{"type":"function","title":"Decimal.abs/1","doc":"The absolute value of given number. Sets the number's sign to positive.","ref":"Decimal.html#abs/1"},{"type":"function","title":"Examples - Decimal.abs/1","doc":"iex> Decimal.abs(Decimal.new(\"1\"))\n    Decimal.new(\"1\")\n\n    iex> Decimal.abs(Decimal.new(\"-1\"))\n    Decimal.new(\"1\")\n\n    iex> Decimal.abs(Decimal.new(\"NaN\"))\n    Decimal.new(\"NaN\")","ref":"Decimal.html#abs/1-examples"},{"type":"function","title":"Decimal.add/2","doc":"Adds two numbers together.","ref":"Decimal.html#add/2"},{"type":"function","title":"Exceptional conditions - Decimal.add/2","doc":"* If one number is -Infinity and the other +Infinity, `:invalid_operation` will\n    be signalled.","ref":"Decimal.html#add/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.add/2","doc":"iex> Decimal.add(1, \"1.1\")\n    Decimal.new(\"2.1\")\n\n    iex> Decimal.add(1, \"Inf\")\n    Decimal.new(\"Infinity\")","ref":"Decimal.html#add/2-examples"},{"type":"function","title":"Decimal.apply_context/1","doc":"Applies the context to the given number rounding it to specified precision.","ref":"Decimal.html#apply_context/1"},{"type":"function","title":"Decimal.cast/1","doc":"Creates a new decimal number from an integer, string, float, or existing decimal number.\n\nBecause conversion from a floating point number is not exact, it's recommended\nto instead use `new/1` or `from_float/1` when the argument's type is certain.\nSee `from_float/1`.","ref":"Decimal.html#cast/1"},{"type":"function","title":"Examples - Decimal.cast/1","doc":"iex> {:ok, decimal} = Decimal.cast(3)\n    iex> decimal\n    Decimal.new(\"3\")\n\n    iex> Decimal.cast(\"bad\")\n    :error","ref":"Decimal.html#cast/1-examples"},{"type":"function","title":"Decimal.cmp/2","doc":"","ref":"Decimal.html#cmp/2"},{"type":"function","title":"Decimal.compare/2","doc":"Compares two numbers numerically. If the first number is greater than the second\n`:gt` is returned, if less than `:lt` is returned, if both numbers are equal\n`:eq` is returned.\n\nNeither number can be a NaN.","ref":"Decimal.html#compare/2"},{"type":"function","title":"Examples - Decimal.compare/2","doc":"iex> Decimal.compare(\"1.0\", 1)\n    :eq\n\n    iex> Decimal.compare(\"Inf\", -1)\n    :gt","ref":"Decimal.html#compare/2-examples"},{"type":"function","title":"Decimal.compare/3","doc":"Compares two numbers numerically using a threshold. If the first number added\nto the threshold is greater than the second number, and the first number\nsubtracted by the threshold is smaller than the second number, then the two\nnumbers are considered equal.","ref":"Decimal.html#compare/3"},{"type":"function","title":"Examples - Decimal.compare/3","doc":"iex> Decimal.compare(\"1.1\", 1, \"0.2\")\n    :eq\n\n    iex> Decimal.compare(\"1.2\", 1, \"0.1\")\n    :gt\n\n    iex> Decimal.compare(\"1.0\", \"1.2\", \"0.1\")\n    :lt","ref":"Decimal.html#compare/3-examples"},{"type":"function","title":"Decimal.div/2","doc":"Divides two numbers.","ref":"Decimal.html#div/2"},{"type":"function","title":"Exceptional conditions - Decimal.div/2","doc":"* If both numbers are ±Infinity `:invalid_operation` is signalled.\n  * If both numbers are ±0 `:invalid_operation` is signalled.\n  * If second number (denominator) is ±0 `:division_by_zero` is signalled.","ref":"Decimal.html#div/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.div/2","doc":"iex> Decimal.div(3, 4)\n    Decimal.new(\"0.75\")\n\n    iex> Decimal.div(\"Inf\", -1)\n    Decimal.new(\"-Infinity\")","ref":"Decimal.html#div/2-examples"},{"type":"function","title":"Decimal.div_int/2","doc":"Divides two numbers and returns the integer part.","ref":"Decimal.html#div_int/2"},{"type":"function","title":"Exceptional conditions - Decimal.div_int/2","doc":"* If both numbers are ±Infinity `:invalid_operation` is signalled.\n  * If both numbers are ±0 `:invalid_operation` is signalled.\n  * If second number (denominator) is ±0 `:division_by_zero` is signalled.","ref":"Decimal.html#div_int/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.div_int/2","doc":"iex> Decimal.div_int(5, 2)\n    Decimal.new(\"2\")\n\n    iex> Decimal.div_int(\"Inf\", -1)\n    Decimal.new(\"-Infinity\")","ref":"Decimal.html#div_int/2-examples"},{"type":"function","title":"Decimal.div_rem/2","doc":"Integer division of two numbers and the remainder. Should be used when both\n`div_int/2` and `rem/2` is needed. Equivalent to: `{Decimal.div_int(x, y),\nDecimal.rem(x, y)}`.","ref":"Decimal.html#div_rem/2"},{"type":"function","title":"Exceptional conditions - Decimal.div_rem/2","doc":"* If both numbers are ±Infinity `:invalid_operation` is signalled.\n  * If both numbers are ±0 `:invalid_operation` is signalled.\n  * If second number (denominator) is ±0 `:division_by_zero` is signalled.","ref":"Decimal.html#div_rem/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.div_rem/2","doc":"iex> Decimal.div_rem(5, 2)\n    {Decimal.new(2), Decimal.new(1)}","ref":"Decimal.html#div_rem/2-examples"},{"type":"function","title":"Decimal.eq?/2","doc":"Compares two numbers numerically and returns `true` if they are equal,\notherwise `false`. If one of the operands is a quiet NaN this operation\nwill always return `false`.","ref":"Decimal.html#eq?/2"},{"type":"function","title":"Examples - Decimal.eq?/2","doc":"iex> Decimal.eq?(\"1.0\", 1)\n    true\n\n    iex> Decimal.eq?(1, -1)\n    false","ref":"Decimal.html#eq?/2-examples"},{"type":"function","title":"Decimal.eq?/3","doc":"It compares the equality of two numbers. If the second number is within\nthe range of first - threshold and first + threshold, it returns true;\notherwise, it returns false.","ref":"Decimal.html#eq?/3"},{"type":"function","title":"Examples - Decimal.eq?/3","doc":"iex> Decimal.eq?(\"1.0\", 1, \"0\")\n    true\n\n    iex> Decimal.eq?(\"1.2\", 1, \"0.1\")\n    false\n\n    iex> Decimal.eq?(\"1.2\", 1, \"0.2\")\n    true\n\n    iex> Decimal.eq?(1, -1, \"0.0\")\n    false","ref":"Decimal.html#eq?/3-examples"},{"type":"function","title":"Decimal.equal?/2","doc":"Compares two numbers numerically and returns `true` if they are equal,\notherwise `false`. If one of the operands is a quiet NaN this operation\nwill always return `false`.","ref":"Decimal.html#equal?/2"},{"type":"function","title":"Examples - Decimal.equal?/2","doc":"iex> Decimal.equal?(\"1.0\", 1)\n    true\n\n    iex> Decimal.equal?(1, -1)\n    false","ref":"Decimal.html#equal?/2-examples"},{"type":"function","title":"Decimal.from_float/1","doc":"Creates a new decimal number from a floating point number.\n\nFloating point numbers use a fixed number of binary digits to represent\na decimal number which has inherent inaccuracy as some decimal numbers cannot\nbe represented exactly in limited precision binary.\n\nFloating point numbers will be converted to decimal numbers with\n`:io_lib_format.fwrite_g/1`. Since this conversion is not exact and\nbecause of inherent inaccuracy mentioned above, we may run into counter-intuitive results:\n\n    iex> Enum.reduce([0.1, 0.1, 0.1], &+/2)\n    0.30000000000000004\n\n    iex> Enum.reduce([Decimal.new(\"0.1\"), Decimal.new(\"0.1\"), Decimal.new(\"0.1\")], &Decimal.add/2)\n    Decimal.new(\"0.3\")\n\nFor this reason, it's recommended to build decimals with `new/1`, which is always precise, instead.","ref":"Decimal.html#from_float/1"},{"type":"function","title":"Examples - Decimal.from_float/1","doc":"iex> Decimal.from_float(3.14)\n    Decimal.new(\"3.14\")","ref":"Decimal.html#from_float/1-examples"},{"type":"function","title":"Decimal.gt?/2","doc":"Compares two numbers numerically and returns `true` if the first argument\nis greater than the second, otherwise `false`. If one the operands is a\nquiet NaN this operation will always return `false`.","ref":"Decimal.html#gt?/2"},{"type":"function","title":"Examples - Decimal.gt?/2","doc":"iex> Decimal.gt?(\"1.3\", \"1.2\")\n    true\n\n    iex> Decimal.gt?(\"1.2\", \"1.3\")\n    false","ref":"Decimal.html#gt?/2-examples"},{"type":"function","title":"Decimal.gte?/2","doc":"Compares two numbers numerically and returns `true` if\nthe first argument is greater than or equal the second,\notherwise `false`.\n\nIf one the operands is a quiet NaN this operation\nwill always return `false`.","ref":"Decimal.html#gte?/2"},{"type":"function","title":"Examples - Decimal.gte?/2","doc":"iex> Decimal.gte?(\"1.3\", \"1.3\")\n    true\n\n    iex> Decimal.gte?(\"1.3\", \"1.2\")\n    true\n\n    iex> Decimal.gte?(\"1.2\", \"1.3\")\n    false","ref":"Decimal.html#gte?/2-examples"},{"type":"function","title":"Decimal.inf?/1","doc":"Returns `true` if number is ±Infinity, otherwise `false`.","ref":"Decimal.html#inf?/1"},{"type":"function","title":"Examples - Decimal.inf?/1","doc":"iex> Decimal.inf?(Decimal.new(\"+Infinity\"))\n    true\n\n    iex> Decimal.inf?(Decimal.new(\"-Infinity\"))\n    true\n\n    iex> Decimal.inf?(Decimal.new(\"1.5\"))\n    false","ref":"Decimal.html#inf?/1-examples"},{"type":"function","title":"Decimal.integer?/1","doc":"Returns `true` when the given `decimal` has no significant digits after the decimal point.","ref":"Decimal.html#integer?/1"},{"type":"function","title":"Examples - Decimal.integer?/1","doc":"iex> Decimal.integer?(\"1.00\")\n    true\n\n    iex> Decimal.integer?(\"1.10\")\n    false","ref":"Decimal.html#integer?/1-examples"},{"type":"macro","title":"Decimal.is_decimal/1","doc":"Returns `true` if argument is a decimal number, otherwise `false`.","ref":"Decimal.html#is_decimal/1"},{"type":"macro","title":"Examples - Decimal.is_decimal/1","doc":"iex> Decimal.is_decimal(Decimal.new(42))\n    true\n\n    iex> Decimal.is_decimal(42)\n    false\n\nAllowed in guard tests on OTP 21+.","ref":"Decimal.html#is_decimal/1-examples"},{"type":"function","title":"Decimal.lt?/2","doc":"Compares two numbers numerically and returns `true` if the first number is\nless than the second number, otherwise `false`. If one of the operands is a\nquiet NaN this operation will always return `false`.","ref":"Decimal.html#lt?/2"},{"type":"function","title":"Examples - Decimal.lt?/2","doc":"iex> Decimal.lt?(\"1.1\", \"1.2\")\n    true\n\n    iex> Decimal.lt?(\"1.4\", \"1.2\")\n    false","ref":"Decimal.html#lt?/2-examples"},{"type":"function","title":"Decimal.lte?/2","doc":"Compares two numbers numerically and returns `true` if\nthe first number is less than or equal the second number,\notherwise `false`.\n\nIf one of the operands is a quiet NaN this operation\nwill always return `false`.","ref":"Decimal.html#lte?/2"},{"type":"function","title":"Examples - Decimal.lte?/2","doc":"iex> Decimal.lte?(\"1.1\", \"1.1\")\n    true\n\n    iex> Decimal.lte?(\"1.1\", \"1.2\")\n    true\n\n    iex> Decimal.lte?(\"1.4\", \"1.2\")\n    false","ref":"Decimal.html#lte?/2-examples"},{"type":"function","title":"Decimal.max/2","doc":"Compares two values numerically and returns the maximum. Unlike most other\nfunctions in `Decimal` if a number is NaN the result will be the other number.\nOnly if both numbers are NaN will NaN be returned.","ref":"Decimal.html#max/2"},{"type":"function","title":"Examples - Decimal.max/2","doc":"iex> Decimal.max(1, \"2.0\")\n    Decimal.new(\"2.0\")\n\n    iex> Decimal.max(1, \"NaN\")\n    Decimal.new(\"1\")\n\n    iex> Decimal.max(\"NaN\", \"NaN\")\n    Decimal.new(\"NaN\")","ref":"Decimal.html#max/2-examples"},{"type":"function","title":"Decimal.min/2","doc":"Compares two values numerically and returns the minimum. Unlike most other\nfunctions in `Decimal` if a number is NaN the result will be the other number.\nOnly if both numbers are NaN will NaN be returned.","ref":"Decimal.html#min/2"},{"type":"function","title":"Examples - Decimal.min/2","doc":"iex> Decimal.min(1, \"2.0\")\n    Decimal.new(\"1\")\n\n    iex> Decimal.min(1, \"NaN\")\n    Decimal.new(\"1\")\n\n    iex> Decimal.min(\"NaN\", \"NaN\")\n    Decimal.new(\"NaN\")","ref":"Decimal.html#min/2-examples"},{"type":"function","title":"Decimal.mult/2","doc":"Multiplies two numbers.","ref":"Decimal.html#mult/2"},{"type":"function","title":"Exceptional conditions - Decimal.mult/2","doc":"* If one number is ±0 and the other is ±Infinity `:invalid_operation` is\n    signalled.","ref":"Decimal.html#mult/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.mult/2","doc":"iex> Decimal.mult(\"0.5\", 3)\n    Decimal.new(\"1.5\")\n\n    iex> Decimal.mult(\"Inf\", -1)\n    Decimal.new(\"-Infinity\")","ref":"Decimal.html#mult/2-examples"},{"type":"function","title":"Decimal.nan?/1","doc":"Returns `true` if number is NaN, otherwise `false`.","ref":"Decimal.html#nan?/1"},{"type":"function","title":"Examples - Decimal.nan?/1","doc":"iex> Decimal.nan?(Decimal.new(\"NaN\"))\n    true\n\n    iex> Decimal.nan?(Decimal.new(42))\n    false","ref":"Decimal.html#nan?/1-examples"},{"type":"function","title":"Decimal.negate/1","doc":"Negates the given number.","ref":"Decimal.html#negate/1"},{"type":"function","title":"Examples - Decimal.negate/1","doc":"iex> Decimal.negate(1)\n    Decimal.new(\"-1\")\n\n    iex> Decimal.negate(\"-Inf\")\n    Decimal.new(\"Infinity\")","ref":"Decimal.html#negate/1-examples"},{"type":"function","title":"Decimal.negative?/1","doc":"Returns `true` if given number is negative, otherwise `false`.","ref":"Decimal.html#negative?/1"},{"type":"function","title":"Examples - Decimal.negative?/1","doc":"iex> Decimal.negative?(Decimal.new(\"-42\"))\n    true\n\n    iex> Decimal.negative?(Decimal.new(\"42\"))\n    false\n\n    iex> Decimal.negative?(Decimal.new(\"0\"))\n    false\n\n    iex> Decimal.negative?(Decimal.new(\"NaN\"))\n    false","ref":"Decimal.html#negative?/1-examples"},{"type":"function","title":"Decimal.new/1","doc":"Creates a new decimal number from an integer or a string representation.\n\nA decimal number will always be created exactly as specified with all digits\nkept - it will not be rounded with the context.","ref":"Decimal.html#new/1"},{"type":"function","title":"Backus–Naur form - Decimal.new/1","doc":"sign           ::=  \"+\" | \"-\"\n    digit          ::=  \"0\" | \"1\" | \"2\" | \"3\" | \"4\" | \"5\" | \"6\" | \"7\" | \"8\" | \"9\"\n    indicator      ::=  \"e\" | \"E\"\n    digits         ::=  digit [digit]...\n    decimal-part   ::=  digits \".\" [digits] | [\".\"] digits\n    exponent-part  ::=  indicator [sign] digits\n    infinity       ::=  \"Infinity\" | \"Inf\"\n    nan            ::=  \"NaN\" [digits]\n    numeric-value  ::=  decimal-part [exponent-part] | infinity\n    numeric-string ::=  [sign] numeric-value | [sign] nan","ref":"Decimal.html#new/1-backus-naur-form"},{"type":"function","title":"Floats - Decimal.new/1","doc":"See also `from_float/1`.","ref":"Decimal.html#new/1-floats"},{"type":"function","title":"Examples - Decimal.new/1","doc":"iex> Decimal.new(1)\n    Decimal.new(\"1\")\n\n    iex> Decimal.new(\"3.14\")\n    Decimal.new(\"3.14\")","ref":"Decimal.html#new/1-examples"},{"type":"function","title":"Decimal.new/3","doc":"Creates a new decimal number from the sign, coefficient and exponent such that\nthe number will be: `sign * coefficient * 10 ^ exponent`.\n\nA decimal number will always be created exactly as specified with all digits\nkept - it will not be rounded with the context.","ref":"Decimal.html#new/3"},{"type":"function","title":"Examples - Decimal.new/3","doc":"iex> Decimal.new(1, 42, 0)\n    Decimal.new(\"42\")","ref":"Decimal.html#new/3-examples"},{"type":"function","title":"Decimal.normalize/1","doc":"Normalizes the given decimal: removes trailing zeros from coefficient while\nkeeping the number numerically equivalent by increasing the exponent.","ref":"Decimal.html#normalize/1"},{"type":"function","title":"Examples - Decimal.normalize/1","doc":"iex> Decimal.normalize(Decimal.new(\"1.00\"))\n    Decimal.new(\"1\")\n\n    iex> Decimal.normalize(Decimal.new(\"1.01\"))\n    Decimal.new(\"1.01\")","ref":"Decimal.html#normalize/1-examples"},{"type":"function","title":"Decimal.parse/1","doc":"Parses a binary into a decimal.\n\nIf successful, returns a tuple in the form of `{decimal, remainder_of_binary}`,\notherwise `:error`.","ref":"Decimal.html#parse/1"},{"type":"function","title":"Examples - Decimal.parse/1","doc":"iex> Decimal.parse(\"3.14\")\n    {%Decimal{coef: 314, exp: -2, sign: 1}, \"\"}\n\n    iex> Decimal.parse(\"3.14.15\")\n    {%Decimal{coef: 314, exp: -2, sign: 1}, \".15\"}\n\n    iex> Decimal.parse(\"-1.1e3\")\n    {%Decimal{coef: 11, exp: 2, sign: -1}, \"\"}\n\n    iex> Decimal.parse(\"bad\")\n    :error","ref":"Decimal.html#parse/1-examples"},{"type":"function","title":"Decimal.positive?/1","doc":"Returns `true` if given number is positive, otherwise `false`.","ref":"Decimal.html#positive?/1"},{"type":"function","title":"Examples - Decimal.positive?/1","doc":"iex> Decimal.positive?(Decimal.new(\"42\"))\n    true\n\n    iex> Decimal.positive?(Decimal.new(\"-42\"))\n    false\n\n    iex> Decimal.positive?(Decimal.new(\"0\"))\n    false\n\n    iex> Decimal.positive?(Decimal.new(\"NaN\"))\n    false","ref":"Decimal.html#positive?/1-examples"},{"type":"function","title":"Decimal.rem/2","doc":"Remainder of integer division of two numbers. The result will have the sign of\nthe first number.","ref":"Decimal.html#rem/2"},{"type":"function","title":"Exceptional conditions - Decimal.rem/2","doc":"* If both numbers are ±Infinity `:invalid_operation` is signalled.\n  * If both numbers are ±0 `:invalid_operation` is signalled.\n  * If second number (denominator) is ±0 `:division_by_zero` is signalled.","ref":"Decimal.html#rem/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.rem/2","doc":"iex> Decimal.rem(5, 2)\n    Decimal.new(\"1\")","ref":"Decimal.html#rem/2-examples"},{"type":"function","title":"Decimal.round/3","doc":"Rounds the given number to specified decimal places with the given strategy\n(default is to round to nearest one). If places is negative, at least that\nmany digits to the left of the decimal point will be zero.\n\nSee `Decimal.Context` for more information about rounding algorithms.","ref":"Decimal.html#round/3"},{"type":"function","title":"Examples - Decimal.round/3","doc":"iex> Decimal.round(\"1.234\")\n    Decimal.new(\"1\")\n\n    iex> Decimal.round(\"1.234\", 1)\n    Decimal.new(\"1.2\")","ref":"Decimal.html#round/3-examples"},{"type":"function","title":"Decimal.scale/1","doc":"Returns the scale of the decimal.\n\nA decimal's scale is the number of digits after the decimal point. This\nincludes trailing zeros; see `normalize/1` to remove them.","ref":"Decimal.html#scale/1"},{"type":"function","title":"Examples - Decimal.scale/1","doc":"iex> Decimal.scale(Decimal.new(\"42\"))\n    0\n\n    iex> Decimal.scale(Decimal.new(1, 2, 26))\n    0\n\n    iex> Decimal.scale(Decimal.new(\"99.12345\"))\n    5\n\n    iex> Decimal.scale(Decimal.new(\"1.50\"))\n    2","ref":"Decimal.html#scale/1-examples"},{"type":"function","title":"Decimal.sqrt/1","doc":"Finds the square root.","ref":"Decimal.html#sqrt/1"},{"type":"function","title":"Examples - Decimal.sqrt/1","doc":"iex> Decimal.sqrt(\"100\")\n    Decimal.new(\"10\")","ref":"Decimal.html#sqrt/1-examples"},{"type":"function","title":"Decimal.sub/2","doc":"Subtracts second number from the first. Equivalent to `Decimal.add/2` when the\nsecond number's sign is negated.","ref":"Decimal.html#sub/2"},{"type":"function","title":"Exceptional conditions - Decimal.sub/2","doc":"* If one number is -Infinity and the other +Infinity `:invalid_operation` will\n    be signalled.","ref":"Decimal.html#sub/2-exceptional-conditions"},{"type":"function","title":"Examples - Decimal.sub/2","doc":"iex> Decimal.sub(1, \"0.1\")\n    Decimal.new(\"0.9\")\n\n    iex> Decimal.sub(1, \"Inf\")\n    Decimal.new(\"-Infinity\")","ref":"Decimal.html#sub/2-examples"},{"type":"function","title":"Decimal.to_float/1","doc":"Returns the decimal converted to a float.\n\nThe returned float may have lower precision than the decimal. Fails if\nthe decimal cannot be converted to a float.","ref":"Decimal.html#to_float/1"},{"type":"function","title":"Examples - Decimal.to_float/1","doc":"iex> Decimal.to_float(Decimal.new(\"1.5\"))\n    1.5","ref":"Decimal.html#to_float/1-examples"},{"type":"function","title":"Decimal.to_integer/1","doc":"Returns the decimal represented as an integer.\n\nFails when loss of precision will occur.","ref":"Decimal.html#to_integer/1"},{"type":"function","title":"Examples - Decimal.to_integer/1","doc":"iex> Decimal.to_integer(Decimal.new(\"42\"))\n    42\n\n    iex> Decimal.to_integer(Decimal.new(\"1.00\"))\n    1\n\n    iex> Decimal.to_integer(Decimal.new(\"1.10\"))\n    ** (ArgumentError) cannot convert Decimal.new(\"1.1\") without losing precision. Use Decimal.round/3 first.","ref":"Decimal.html#to_integer/1-examples"},{"type":"function","title":"Decimal.to_string/2","doc":"Converts given number to its string representation.","ref":"Decimal.html#to_string/2"},{"type":"function","title":"Options - Decimal.to_string/2","doc":"* `:scientific` - number converted to scientific notation.\n  * `:normal` - number converted without a exponent.\n  * `:xsd` - number converted to the [canonical XSD representation](https://www.w3.org/TR/xmlschema-2/#decimal).\n  * `:raw` - number converted to its raw, internal format.","ref":"Decimal.html#to_string/2-options"},{"type":"function","title":"Examples - Decimal.to_string/2","doc":"iex> Decimal.to_string(Decimal.new(\"1.00\"))\n    \"1.00\"\n\n    iex> Decimal.to_string(Decimal.new(\"123e1\"), :scientific)\n    \"1.23E+3\"\n\n    iex> Decimal.to_string(Decimal.new(\"42.42\"), :normal)\n    \"42.42\"\n\n    iex> Decimal.to_string(Decimal.new(\"1.00\"), :xsd)\n    \"1.0\"\n\n    iex> Decimal.to_string(Decimal.new(\"4321.768\"), :raw)\n    \"4321768E-3\"","ref":"Decimal.html#to_string/2-examples"},{"type":"type","title":"Decimal.coefficient/0","doc":"The coefficient of the power of `10`. Non-negative because the sign is stored separately in `sign`.\n\n  * `non_neg_integer` - when the `t` represents a number, instead of one of the special values below.\n  * `:NaN` - Not a Number.\n  * `:inf` - Infinity.","ref":"Decimal.html#t:coefficient/0"},{"type":"type","title":"Decimal.compare_result/0","doc":"","ref":"Decimal.html#t:compare_result/0"},{"type":"type","title":"Decimal.decimal/0","doc":"","ref":"Decimal.html#t:decimal/0"},{"type":"type","title":"Decimal.exponent/0","doc":"The exponent to which `10` is raised.","ref":"Decimal.html#t:exponent/0"},{"type":"type","title":"Decimal.rounding/0","doc":"Rounding algorithm.\n\nSee `Decimal.Context` for more information.","ref":"Decimal.html#t:rounding/0"},{"type":"type","title":"Decimal.sign/0","doc":"* `1` for positive\n  * `-1` for negative","ref":"Decimal.html#t:sign/0"},{"type":"type","title":"Decimal.signal/0","doc":"","ref":"Decimal.html#t:signal/0"},{"type":"type","title":"Decimal.t/0","doc":"This implementation models the `sign` as `1` or `-1` such that the complete number will be: `sign * coef * 10 ^ exp`.\n\n  * `coef` - the coefficient of the power of `10`.\n  * `exp` - the exponent of the power of `10`.\n  * `sign` - `1` for positive, `-1` for negative.","ref":"Decimal.html#t:t/0"},{"type":"module","title":"Decimal.Context","doc":"The context is kept in the process dictionary. It can be accessed with\n`get/0` and `set/1`.\n\nThe default context has a precision of 28, the rounding algorithm is\n`:half_up`. The set trap enablers are `:invalid_operation` and\n`:division_by_zero`.","ref":"Decimal.Context.html"},{"type":"module","title":"Fields - Decimal.Context","doc":"* `precision` - maximum number of decimal digits in the coefficient. If an\n    operation result has more digits it will be rounded to `precision`\n    digits with the rounding algorithm in `rounding`.\n  * `rounding` - the rounding algorithm used when the coefficient's number of\n    exceeds `precision`. Strategies explained below.\n  * `flags` - a list of signals that for which the flag is sent. When an\n    exceptional condition is signalled its flag is set. The flags are sticky\n    and will be set until explicitly cleared.\n  * `traps` - a list of set trap enablers for signals. When a signal's trap\n    enabler is set the condition causes `Decimal.Error` to be raised.","ref":"Decimal.Context.html#module-fields"},{"type":"module","title":"Rounding algorithms - Decimal.Context","doc":"* `:down` - round toward zero (truncate). Discarded digits are ignored,\n    result is unchanged.\n  * `:half_up` - if the discarded digits is greater than or equal to half of\n    the value of a one in the next left position then the coefficient will be\n    incremented by one (rounded up). Otherwise (the discarded digits are less\n    than half) the discarded digits will be ignored.\n  * `:half_even` - also known as \"round to nearest\" or \"banker's rounding\". If\n    the discarded digits is greater than half of the value of a one in the\n    next left position then the coefficient will be incremented by one\n    (rounded up). If they represent less than half discarded digits will be\n    ignored. Otherwise (exactly half), the coefficient is not altered if it's\n    even, or incremented by one (rounded up) if it's odd (to make an even\n    number).\n  * `:ceiling` - round toward +Infinity. If all of the discarded digits are\n    zero or the sign is negative the result is unchanged. Otherwise, the\n    coefficient will be incremented by one (rounded up).\n  * `:floor` - round toward -Infinity. If all of the discarded digits are zero\n    or the sign is positive the result is unchanged. Otherwise, the sign is\n    negative and coefficient will be incremented by one.\n  * `:half_down` - if the discarded digits is greater than half of the value\n    of a one in the next left position then the coefficient will be\n    incremented by one (rounded up). Otherwise (the discarded digits are half\n    or less) the discarded digits are ignored.\n  * `:up` - round away from zero. If all discarded digits are zero the\n    coefficient is not changed, otherwise it is incremented by one (rounded\n    up).\n\nThis table shows the results of rounding operations for all the rounding\nalgorithms:\n\nRounding algorithm | 5.5 | 2.5 | 1.6 | 1.1 | 1.0 | -1.0 | -1.1 | -1.6 | -2.5 | -5.5\n:----------------- | :-- | :-- | :-- | :-- | :-- | :--- | :--- | :--- | :--- | :---\n`:up`              |   6 |   3 |   2 |   2 |   1 |   -1 |   -2 |   -2 |   -3 |   -6\n`:down`            |   5 |   2 |   1 |   1 |   1 |   -1 |   -1 |   -1 |   -2 |   -5\n`:ceiling`         |   6 |   3 |   2 |   2 |   1 |   -1 |   -1 |   -1 |   -2 |   -5\n`:floor`           |   5 |   2 |   1 |   1 |   1 |   -1 |   -2 |   -2 |   -3 |   -6\n`:half_up`         |   6 |   3 |   2 |   1 |   1 |   -1 |   -1 |   -2 |   -3 |   -6\n`:half_down`       |   5 |   2 |   2 |   1 |   1 |   -1 |   -1 |   -2 |   -2 |   -5\n`:half_even`       |   6 |   2 |   2 |   1 |   1 |   -1 |   -1 |   -2 |   -2 |   -6","ref":"Decimal.Context.html#module-rounding-algorithms"},{"type":"function","title":"Decimal.Context.get/0","doc":"Gets the process' context.","ref":"Decimal.Context.html#get/0"},{"type":"function","title":"Decimal.Context.set/1","doc":"Set the process' context.","ref":"Decimal.Context.html#set/1"},{"type":"function","title":"Decimal.Context.update/1","doc":"Update the process' context.","ref":"Decimal.Context.html#update/1"},{"type":"function","title":"Decimal.Context.with/2","doc":"Runs function with given context.","ref":"Decimal.Context.html#with/2"},{"type":"type","title":"Decimal.Context.t/0","doc":"","ref":"Decimal.Context.html#t:t/0"},{"type":"exception","title":"Decimal.Error","doc":"The exception that all decimal operations may raise.","ref":"Decimal.Error.html"},{"type":"exception","title":"Fields - Decimal.Error","doc":"* `signal` - the signalled error, additional signalled errors will be found\n    in the context.\n  * `reason` - the reason for the error.\n\nRescuing the error to access the result or the other fields of the error is\ndiscouraged and should only be done for exceptional conditions. It is more\npragmatic to set the appropriate traps on the context and check the flags\nafter the operation if the result needs to be inspected.","ref":"Decimal.Error.html#module-fields"},{"type":"extras","title":"Decimal","doc":"# Decimal\n\nArbitrary precision decimal arithmetic.","ref":"readme.html"},{"type":"extras","title":"Concept - Decimal","doc":"Decimal represents values internally using three integers: a sign, a coefficient, and an exponent.\nIn this way, numbers of any size and with any number of decimal places can be represented exactly.\n\n```elixir\nDecimal.new(_sign = 1, _coefficient = 42, _exponent = 0) #=> Decimal.new(\"42\")\nDecimal.new(-1, 42, 0) #=> Decimal.new(\"-42\")\nDecimal.new(1, 42, -1) #=> Decimal.new(\"4.2\")\nDecimal.new(1, 42, -20) #=> Decimal.new(\"4.2E-19\")\nDecimal.new(1, 42, 20) #=> Decimal.new(\"4.2E+21\")\nDecimal.new(1, 123456789987654321, -9) #=> Decimal.new(\"123456789.987654321\")\n```\n\nFor calculations, the amount of desired precision - that is, the number of\ndecimal digits in the coefficient - can be specified.","ref":"readme.html#concept"},{"type":"extras","title":"Usage - Decimal","doc":"Add Decimal as a dependency in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [{:decimal, \"~> 2.0\"}]\nend\n```\n\nNext, run `mix deps.get` in your shell to fetch and compile `Decimal`. Start an\ninteractive Elixir shell with `iex -S mix`:\n\n```elixir\niex> alias Decimal, as: D\niex> D.add(6, 7)\nDecimal.new(\"13\")\niex> D.div(1, 3)\nDecimal.new(\"0.3333333333333333333333333333\")\niex> D.new(\"0.33\")\nDecimal.new(\"0.33\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Examples - Decimal","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Using the context - Decimal","doc":"The context specifies the maximum precision of the result of calculations and\nthe rounding algorithm if the result has a higher precision than the specified\nmaximum. It also holds the list of trap enablers and the current set\nflags.\n\nThe context is stored in the process dictionary. You don't have to pass the\ncontext around explicitly and the flags will be updated automatically.\n\nThe context is accessed with `Decimal.Context.get/0` and set with\n`Decimal.Context.set/1`. It can be set temporarily with\n`Decimal.Context.with/2`.\n\n```elixir\niex> D.Context.get()\n%Decimal.Context{flags: [:rounded, :inexact], precision: 9, rounding: :half_up,\n traps: [:invalid_operation, :division_by_zero]}\n\niex> D.Context.with(%D.Context{precision: 2}, fn -> IO.inspect D.Context.get() end)\n%Decimal.Context{flags: [], precision: 2, rounding: :half_up,\n traps: [:invalid_operation, :division_by_zero]}\n%Decimal.Context{flags: [], precision: 2, rounding: :half_up,\n traps: [:invalid_operation, :division_by_zero]}\n\niex> D.Context.set(%D.Context{D.Context.get() | traps: []})\n:ok\n\niex> D.Context.get()\n%Decimal.Context{flags: [:rounded, :inexact], precision: 9, rounding: :half_up,\n traps: []}\n```","ref":"readme.html#using-the-context"},{"type":"extras","title":"Precision and rounding - Decimal","doc":"Use `:precision` option to limit the amount of decimal digits in the\ncoefficient of any calculation result:\n\n```elixir\niex> D.Context.set(%D.Context{D.Context.get() | precision: 9})\n:ok\n\niex> D.div(100, 3)\nDecimal.new(\"33.3333333\")\n\niex> D.Context.set(%D.Context{D.Context.get() | precision: 2})\n:ok\n\niex> D.div(100, 3)\nDecimal.new(\"33\")\n```\n\nThe `:rounding` option specifies the algorithm and precision of the rounding\noperation:\n\n```elixir\niex> D.Context.set(%D.Context{D.Context.get() | rounding: :half_up})\n:ok\n\niex> D.div(31, 2)\nDecimal.new(\"16\")\n\niex> D.Context.set(%D.Context{D.Context.get() | rounding: :floor})\n:ok\n\niex> D.div(31, 2)\nDecimal.new(\"15\")\n```","ref":"readme.html#precision-and-rounding"},{"type":"extras","title":"Comparisons - Decimal","doc":"Using comparison operators (`<`, `=`, `>`) with two or more decimal digits may\nnot produce accurate result. Instead, use comparison functions.\n\n```elixir\niex> D.compare(-1, 0)\n:lt\niex> D.compare(0, -1)\n:gt\niex> D.compare(0, 0)\n:eq\n\niex> D.equal?(-1, 0)\nfalse\niex> D.equal?(0, \"0.0\")\ntrue\n```","ref":"readme.html#comparisons"},{"type":"extras","title":"Flags and trap enablers - Decimal","doc":"When an exceptional condition is signalled, its flag is set in the current\ncontext. `Decimal.Error` will be raised if the trap enabler is set.\n\n```elixir\niex> D.Context.set(%D.Context{D.Context.get() | rounding: :floor, precision: 2})\n:ok\n\niex> D.Context.get().traps\n[:invalid_operation, :division_by_zero]\n\niex> D.Context.get().flags\n[]\n\niex> D.div(31, 2)\nDecimal.new(\"15\")\n\niex> D.Context.get().flags\n[:inexact, :rounded]\n```\n\n`:inexact` and `:rounded` flag were signalled above because the result of the\noperation was inexact given the context's precision and had to be rounded to\nfit the precision. `Decimal.Error` was not raised because the signals' trap\nenablers weren't set.\n\n```elixir\niex> D.Context.set(%D.Context{D.Context.get() | traps: D.Context.get().traps ++ [:inexact]})\n:ok\n\niex> D.div(31, 2)\n** (Decimal.Error)\n```\n\nThe default trap enablers, such as `:division_by_zero`, can be unset:\n\n```elixir\niex> D.Context.get().traps\n[:invalid_operation, :division_by_zero]\n\niex> D.div(42, 0)\n** (Decimal.Error)\n\niex> D.Context.set(%D.Context{D.Context.get() | traps: [], flags: []})\n:ok\n\niex> D.div(42, 0)\nDecimal.new(\"Infinity\")\n\niex> D.Context.get().flags\n[:division_by_zero]\n```","ref":"readme.html#flags-and-trap-enablers"},{"type":"extras","title":"Mitigating rounding errors - Decimal","doc":"TODO","ref":"readme.html#mitigating-rounding-errors"},{"type":"extras","title":"License - Decimal","doc":"Copyright 2013 Eric Meadows-Jönsson\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}